@@ -2,7 +2,7 @@
  * Gnome Chemisty Utils
  * gtkchem3dviewer.c 
  *
- * Copyright (C) 2003
+ * Copyright (C) 2003-2004
  *
  * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
  *
@@ -22,6 +22,14 @@
  * Boston, MA  02111-1307, USA.
  */
 
+#include <mol.h>
+#undef PACKAGE
+#undef PACKAGE_BUGREPORT
+#undef PACKAGE_NAME
+#undef PACKAGE_STRING
+#undef PACKAGE_TARNAME
+#undef PACKAGE_VERSION
+#undef VERSION
 #include <libgnomevfs/gnome-vfs.h>
 #include "config.h"
 #include "gtkchem3dviewer.h"
@@ -36,7 +44,6 @@
 #	include <gtk/gtkgl.h>
 #endif
 #include <sstream>
-#	include <mol.h>
 #include <libintl.h>
 #define _(String) gettext(String)
 
